<?php
	add_action( 'wp_enqueue_scripts', 'online_grocery_mart_enqueue_styles' );
	function online_grocery_mart_enqueue_styles() {
    	$parent_style = 'food-grocery-store-basic-style'; // Style handle of parent theme.
		wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css' );		
		wp_enqueue_style( 'online-grocery-mart-style', get_stylesheet_uri(), array( $parent_style ) );
		require get_parent_theme_file_path( '/custom-style.php' );
		wp_add_inline_style( 'online-grocery-mart-style',$food_grocery_store_custom_css );
		require get_theme_file_path( '/custom-style.php' );
		wp_add_inline_style( 'online-grocery-mart-style',$food_grocery_store_custom_css );
		wp_enqueue_style( 'online-grocery-mart-block-style', get_theme_file_uri('/css/blocks.css') );
		wp_enqueue_style( 'online-grocery-mart-block-patterns-style-frontend', get_theme_file_uri('/inc/block-patterns/css/block-frontend.css') );
	}

	add_action( 'init', 'online_grocery_mart_remove_parent_function');
	function online_grocery_mart_remove_parent_function() {
		remove_action( 'admin_notices', 'food_grocery_store_activation_notice' );
		remove_action( 'wp_enqueue_scripts', 'food_grocery_store_header_style' );
		remove_action( 'admin_menu', 'food_grocery_store_gettingstarted' );
	}

	function online_grocery_mart_customize_register() {
		global $wp_customize;
		$wp_customize->remove_section( 'food_grocery_store_upgrade_pro_link' );
		$wp_customize->remove_section( 'food_grocery_store_get_started_link' );
		$wp_customize->remove_setting( 'food_grocery_store_daily_deals_text' );
		$wp_customize->remove_control( 'food_grocery_store_daily_deals_text' );
		$wp_customize->remove_setting( 'food_grocery_store_daily_deals_link' );
		$wp_customize->remove_control( 'food_grocery_store_daily_deals_link' );
		$wp_customize->remove_setting( 'food_grocery_store_contact_text' );
		$wp_customize->remove_control( 'food_grocery_store_contact_text' );
		$wp_customize->remove_setting( 'food_grocery_store_contact_link' );
		$wp_customize->remove_control( 'food_grocery_store_contact_link' );


	}
	add_action( 'customize_register', 'online_grocery_mart_customize_register', 11 );

	function online_grocery_mart_header_style() {
		if ( get_header_image() ) :
		$custom_css = "
	        #header{
				background-image:url('".esc_url(get_header_image())."');
				background-position: center top;
				background-size: 100%;
			}";
		   	wp_add_inline_style( 'online-grocery-mart-style', $custom_css );
		endif;
	}
	add_action( 'wp_enqueue_scripts', 'online_grocery_mart_header_style' );

	function online_grocery_mart_scripts() {	
		wp_enqueue_script( 'Custom JS ', get_stylesheet_directory_uri() . '/js/custom.js', array('jquery') );
	}
	add_action( 'wp_enqueue_scripts', 'online_grocery_mart_scripts' );

	function online_grocery_mart_font_url() {
		$font_url      = '';
		$font_family   = array();
		$font_family[] = 'Prata';
		$font_family[] = 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i';
		$query_args = array(
			'family' => rawurlencode(implode('|', $font_family)),
		);
		$font_url = add_query_arg($query_args, '//fonts.googleapis.com/css');
		return $font_url;
	}
	
	function online_grocery_mart_customizer ( $wp_customize ) {

		// Header
		$wp_customize->add_setting('online_grocery_mart_discount_text',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));	
		$wp_customize->add_control('online_grocery_mart_discount_text',array(
			'label'	=> esc_html__('Discount Text','online-grocery-mart'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'Discount Text', 'online-grocery-mart' ),
	        ),
			'section'=> 'food_grocery_store_top_header',
			'type'=> 'text'
		));

		$wp_customize->add_setting('online_grocery_mart_email_address',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_email'
		));	
		$wp_customize->add_control('online_grocery_mart_email_address',array(
			'label'	=> esc_html__('Email Address','online-grocery-mart'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'Email Address', 'online-grocery-mart' ),
	        ),
			'section'=> 'food_grocery_store_top_header',
			'type'=> 'text'
		));

		$wp_customize->add_setting('online_grocery_mart_hot_deal_text',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));	
		$wp_customize->add_control('online_grocery_mart_hot_deal_text',array(
			'label'	=> esc_html__('Hot Deals Text','online-grocery-mart'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'Hot Deals', 'online-grocery-mart' ),
	        ),
			'section'=> 'food_grocery_store_top_header',
			'type'=> 'text'
		));

		$wp_customize->add_setting('online_grocery_mart_hot_deal_link',array(
			'default'=> '',
			'sanitize_callback'	=> 'esc_url_raw'
		));	
		$wp_customize->add_control('online_grocery_mart_hot_deal_link',array(
			'label'	=> esc_html__('Hot Deals Link','online-grocery-mart'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'https://example.com/page', 'online-grocery-mart' ),
	        ),
			'section'=> 'food_grocery_store_top_header',
			'type'=> 'url'
		));

		//Best Deal
		$wp_customize->add_section( 'online_grocery_mart_best_deal_section' , array(
	    	'title' => esc_html__( 'Deal Of The Day Section', 'online-grocery-mart' ),
			'panel' => 'food_grocery_store_panel_id'
		) );

		$args = array(
	       'type'                     => 'product',
	        'child_of'                 => 0,
	        'parent'                   => '',
	        'orderby'                  => 'term_group',
	        'order'                    => 'ASC',
	        'hide_empty'               => false,
	        'hierarchical'             => 1,
	        'number'                   => '',
	        'taxonomy'                 => 'product_cat',
	        'pad_counts'               => false
	    );
	    $categories = get_categories( $args );
	    $cats = array();
	    $i = 0;
	    foreach($categories as $category){
	        if($i==0){
	            $default = $category->slug;
	            $i++;
	        } 
	        $cats[$category->slug] = $category->name;
	    }
	    $wp_customize->add_setting('online_grocery_mart_best_deal',array(
	        'sanitize_callback' => 'online_grocery_mart_sanitize_select',
	    ));
	    $wp_customize->add_control('online_grocery_mart_best_deal',array(
	        'type'    => 'select',
	        'choices' => $cats,
	        'label' => __('Select Product Category','online-grocery-mart'),
	        'section' => 'online_grocery_mart_best_deal_section',
	    ));
	}
	add_action( 'customize_register', 'online_grocery_mart_customizer' );

	/**
	 * Enqueue block editor style
	 */
	function online_grocery_mart_block_editor_styles() {
		wp_enqueue_style( 'online-grocery-mart-font', online_grocery_mart_font_url(), array() );
	    wp_enqueue_style( 'online-grocery-mart-block-patterns-style-editor', get_theme_file_uri( '/inc/block-patterns/css/block-editor.css' ), false, '1.0', 'all' );
	}
	add_action( 'enqueue_block_editor_assets', 'online_grocery_mart_block_editor_styles' );

	function online_grocery_mart_sanitize_select( $input, $setting ){      
	    $input = sanitize_key($input);
	    $choices = $setting->manager->get_control( $setting->id )->choices;
	    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );      
	}

// Customizer Pro
require_once( ABSPATH . WPINC . '/class-wp-customize-section.php' );

class Online_Grocery_Mart_Customize_Section_Pro extends WP_Customize_Section {
	public $type = 'online-grocery-mart';
	public $pro_text = '';
	public $pro_url = '';
	public function json() {
		$json = parent::json();
		$json['pro_text'] = $this->pro_text;
		$json['pro_url']  = esc_url( $this->pro_url );
		return $json;
	}
	protected function render_template() { ?>
		<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
			<h3 class="accordion-section-title">
				{{ data.title }}
				<# if ( data.pro_text && data.pro_url ) { #>
					<a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
				<# } #>
			</h3>
		</li>
	<?php }
}

final class Online_Grocery_Mart_Customize {
	public static function get_instance() {
		static $instance = null;
		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}
		return $instance;
	}
	private function __construct() {}
	private function setup_actions() {
		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );
		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}
	public function sections( $manager ) {
		// Register custom section types.
		$manager->register_section_type( 'Online_Grocery_Mart_Customize_Section_Pro' );
		// Register sections.
		$manager->add_section( new Online_Grocery_Mart_Customize_Section_Pro( $manager, 'online_grocery_mart',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Online Grocery Mart', 'online-grocery-mart' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'online-grocery-mart' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/online-grocery-shopping-wordpress-theme/'),
		) ) );
	}
	public function enqueue_control_scripts() {
		wp_enqueue_script( 'online-grocery-mart-customize-controls', get_stylesheet_directory_uri() . '/js/customize-controls-child.js', array( 'customize-controls' ) );
		wp_enqueue_style( 'online-grocery-mart-customize-controls', get_stylesheet_directory_uri() . '/css/customize-controls-child.css' );
	}
}
Online_Grocery_Mart_Customize::get_instance();

/* Theme Setup */
if ( ! function_exists( 'online_grocery_mart_setup' ) ) :
 
function online_grocery_mart_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
}
endif;

add_action( 'after_setup_theme', 'online_grocery_mart_setup' );

/* Theme Widgets Setup */
function online_grocery_mart_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Social Icon', 'online-grocery-mart' ),
		'description'   => __( 'Appears on Header', 'online-grocery-mart' ),
		'id'            => 'social-icon',
	) );
}
add_action( 'widgets_init', 'online_grocery_mart_widgets_init' );

/* Social Icons */
require get_theme_file_path() . '/inc/themes-widgets/social-icon.php';